jTWA.spin1 package
==================

Submodules
----------

jTWA.spin1.hamiltonian module
-----------------------------

.. automodule:: jTWA.spin1.hamiltonian
   :members:
   :undoc-members:
   :show-inheritance:

jTWA.spin1.initState module
---------------------------

.. automodule:: jTWA.spin1.initState
   :members:
   :undoc-members:
   :show-inheritance:

jTWA.spin1.observables module
-----------------------------

.. automodule:: jTWA.spin1.observables
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jTWA.spin1
   :members:
   :undoc-members:
   :show-inheritance:
